# state

state label

DynamX state/cluster name: State
HDExaminer name: Protein State


# exposure

Deuterium exposure time in seconds

DynamX state/cluster name: Exposure
HDExaminer name: Deut Time

# file

DynamX cluster name: File
HDExaminer name: Experiment

# centroid_mass
calculated mass of uncharged peptide
derived from charge / centroid

# centroid_mz

HDExaminer name: Exp Cent
DynamX name: ??

# rt

retention time 
units unknown (minutes?)

DynamX state/cluster name: RT
HDExaminer name: Actual RT

# charge

DynamX cluster name: z
HDExaminer name: Charge


# intensity

HDExaminer name: Max Inty
DynamX name?? is this max or mean intensity?